@@ -19,7 +19,7 @@ extends 'HPC::Runner';
 extends 'HPC::Runner::Slurm';
 with 'MooseX::SimpleConfig';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # For pretty man pages!
 $ENV{TERM}='xterm-256color';
@@ -66,7 +66,9 @@ has 'walltime' => (
     is => 'rw',
     isa => 'Str',
     required => 1,
-    default => '04:00:00'
+    default => '04:00:00',
+    predicate => 'has_walltime',
+    clearer => 'clear_walltime,'
 );
 
 =head2 mem
@@ -105,6 +107,9 @@ has '+template_file' => (
 #PBS -N [% JOBNAME %]
 #PBS -q [% PARTITION %]
 #PBS -l nodes=1:ppn=[% CPU %]
+[% IF self.has_walltime %]
+#PBS -l walltime=[% self.walltime %]
+[% END %]
 #PBS -eo localhost:[% OUT %]
 [% IF self.has_mem %]
 #PBS -l mem=[% self.mem %]
